"use strict";
var log4js_ = require("log4js");
var azure_ = require("azure-storage");
var assistant_ = require("./assistant");
function validateField(name, value) {
    var _v = value;
    if (_v == null
        || typeof _v !== 'string'
        || _v.length <= 0) {
        throw new TypeError("[" + name + "] must be a valid string but get " + (typeof _v));
    }
}
function defaultHandler(e, r, res) {
    if (e)
        throw e;
}
function appender(azureStorageConnectionString, container, appendBlob, layout) {
    validateField("azureStorageConnectionString", azureStorageConnectionString);
    validateField("container", container);
    validateField("appendBlob", appendBlob);
    if (layout == null)
        layout = log4js_.layouts.basicLayout;
    var blob = azure_.createBlobService(azureStorageConnectionString);
    blob.createContainerIfNotExists(container, function (error, result, response) {
        if (error)
            throw error;
    });
    var writer = new assistant_.AzureAppendBlobAssistant(blob, container, appendBlob);
    var appenderWriter = function (evt) {
        if (evt == null)
            return;
        var cb = appenderWriter.callback || defaultHandler;
        var text;
        try {
            text = layout(evt);
        }
        catch (e) {
            var error = (e instanceof Error) ? e : new Error(e);
            setTimeout(cb, 0, error, null, null);
            return;
        }
        writer.writeText(text, cb);
    };
    appenderWriter.callback = defaultHandler;
    return appenderWriter;
}
exports.appender = appender;
exports.name = "azure-append-blob-appender";
function configure(config) {
    if (config == null || typeof config !== 'object') {
        throw new Error('Missing required configuration');
    }
    validateField("azureStorageConnectionString", config.azureStorageConnectionString);
    validateField("container", config.container);
    validateField("appendBlob", config.appendBlob);
    var layout;
    if (config.layout) {
        layout = log4js_.layouts.layout(config.layout.type, config.layout);
    }
    if (layout == null)
        layout = log4js_.layouts.basicLayout;
    return appender(config.azureStorageConnectionString, config.container, config.appendBlob, layout);
}
exports.configure = configure;
function shutdown(cb) {
    return cb(null);
}
exports.shutdown = shutdown;
//# sourceMappingURL=appender.js.map