"use strict";
var os_ = require("os");
var util_ = require("util");
var eol = os_.EOL || '\n';
var AzureAppendBlobAssistant = (function () {
    function AzureAppendBlobAssistant(blob, container, blobName) {
        this.blob = blob;
        this.container = container;
        this.blobName = blobName;
        this._checked = false;
    }
    AzureAppendBlobAssistant.prototype.writeText = function (text, callback) {
        var self = this;
        var cb = function (e, r, res) {
            setTimeout(callback, 0, e, r, res);
        };
        text = text + eol;
        if (self._checked)
            return self.blob.appendFromText(self.container, self.blobName, text, cb);
        self.blob.getBlobProperties(self.container, self.blobName, function (error, result, response) {
            self._checked = true;
            if (error != null) {
                if (response != null && response.statusCode == 404) {
                    return self.blob.createAppendBlobFromText(self.container, self.blobName, text, cb);
                }
                return cb(error, result, response);
            }
            else {
                if (result != null && result.blobType !== "AppendBlob") {
                    var msg = util_.format("Azure Storage {container=%s, blob=%s} is not an append blob but [%s]", self.container, self.blobName);
                    return cb(new TypeError(msg), null, null);
                }
                return self.blob.appendFromText(self.container, self.blobName, text, cb);
            }
        });
    };
    return AzureAppendBlobAssistant;
}());
exports.AzureAppendBlobAssistant = AzureAppendBlobAssistant;
//# sourceMappingURL=assistant.js.map